pub enum IpSocketMatcherError {
UnknownUnionVariant(u64),
Address(BoundAddressError),
TransportProtocol(SocketTransportProtocolError),
BoundInterface(BoundInterfaceError),
Mark(MarkInDomainError),
}Expand description
Errors returned by the conversion from [fnet_sockets::IpSocketMatcher]
to IpSocketMatcher.
Variants
UnknownUnionVariant(u64)
A union type was unknown.
Address(BoundAddressError)
An error was encountered when converting one of the address matchers.
TransportProtocol(SocketTransportProtocolError)
An error was encountered when converting the transport protocol matcher.
BoundInterface(BoundInterfaceError)
An error was encountered while converting the interface matcher.
Mark(MarkInDomainError)
An error was encountered when converting one of the mark matchers.