iterate_ip

Function iterate_ip 

pub async fn iterate_ip<M, I>(
    diagnostics: &DiagnosticsProxy,
    extensions: Extensions,
    matchers: M,
) -> Result<impl Stream<Item = Result<IpSocketState, IpIteratorError>>, IterateIpError>
where M: IntoIterator<Item = I>, I: Into<IpSocketMatcher>,
Send a request to Diagnostics.IterateIp and drive the resulting IpIterator.

IpIterator returns a series of batches of sockets matching the query, the returned stream flattens those batches into individual sockets. If an error is encuontered during iteration, it is returned and iteration halts.