pub async fn watch_destruction(
diagnostics: &DiagnosticsProxy,
) -> Result<impl Stream<Item = Result<IpSocketState, DestructionWatcherError>> + use<>, Error>Expand description
Get a destruction watcher and drive it to yield individual sockets.
pub async fn watch_destruction(
diagnostics: &DiagnosticsProxy,
) -> Result<impl Stream<Item = Result<IpSocketState, DestructionWatcherError>> + use<>, Error>Get a destruction watcher and drive it to yield individual sockets.