pub struct TcpInfo {Show 15 fields
pub state: State,
pub ca_state: CongestionControlState,
pub rto_usec: Option<u32>,
pub tcpi_last_data_sent_msec: Option<u32>,
pub tcpi_last_ack_recv_msec: Option<u32>,
pub rtt_usec: Option<u32>,
pub rtt_var_usec: Option<u32>,
pub snd_ssthresh: u32,
pub snd_cwnd: u32,
pub tcpi_total_retrans: u32,
pub tcpi_segs_out: u64,
pub tcpi_segs_in: u64,
pub reorder_seen: bool,
pub tcpi_snd_mss: Option<u32>,
pub tcpi_rcv_mss: Option<u32>,
}Expand description
Extension type for [fnet_tcp::Info].
Fields
state: StateThe state of the TCP connection.
ca_state: CongestionControlStateThe congestion control state of the TCP connection.
rto_usec: Option<u32>The retransmission timeout of the TCP connection in microseconds.
tcpi_last_data_sent_msec: Option<u32>The time since the most recent data was sent on the connection in milliseconds.
tcpi_last_ack_recv_msec: Option<u32>The time since the most recent ACK was received in milliseconds.
rtt_usec: Option<u32>The estimated smoothed roundtrip time in microseconds.
rtt_var_usec: Option<u32>The smoothed mean deviation of the roundtrip time in microseconds.
snd_ssthresh: u32The sending slow start threshold in segments.
snd_cwnd: u32The current sending congestion window in segments.
tcpi_total_retrans: u32The total number of retransmissions.
tcpi_segs_out: u64The total number of segments sent.
tcpi_segs_in: u64The total number of segments received.
reorder_seen: boolWhether reordering has been seen on the connection.
tcpi_snd_mss: Option<u32>The send MSS for this endpoint.
tcpi_rcv_mss: Option<u32>The receive MSS for this endpoint.