TcpInfo

Struct TcpInfo 

pub struct TcpInfo {
Show 13 fields pub state: State, pub ca_state: CongestionControlState, pub rto_usec: Option<u32>, pub tcpi_last_data_sent_msec: Option<u32>, pub tcpi_last_ack_recv_msec: Option<u32>, pub rtt_usec: Option<u32>, pub rtt_var_usec: Option<u32>, pub snd_ssthresh: u32, pub snd_cwnd: u32, pub tcpi_total_retrans: u32, pub tcpi_segs_out: u64, pub tcpi_segs_in: u64, pub reorder_seen: bool,
}
Extension type for [fnet_tcp::Info].

Fields

state: State

The state of the TCP connection.

ca_state: CongestionControlState

The congestion control state of the TCP connection.

rto_usec: Option<u32>

The retransmission timeout of the TCP connection in microseconds.

tcpi_last_data_sent_msec: Option<u32>

The time since the most recent data was sent on the connection in milliseconds.

tcpi_last_ack_recv_msec: Option<u32>

The time since the most recent ACK was received in milliseconds.

rtt_usec: Option<u32>

The estimated smoothed roundtrip time in microseconds.

rtt_var_usec: Option<u32>

The smoothed mean deviation of the roundtrip time in microseconds.

snd_ssthresh: u32

The sending slow start threshold in segments.

snd_cwnd: u32

The current sending congestion window in segments.

tcpi_total_retrans: u32

The total number of retransmissions.

tcpi_segs_out: u64

The total number of segments sent.

tcpi_segs_in: u64

The total number of segments received.

reorder_seen: bool

Whether reordering has been seen on the connection.